summaryrefslogtreecommitdiffstats
path: root/kexi/plugins/macros/kexipart/keximacroview.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/plugins/macros/kexipart/keximacroview.cpp')
-rw-r--r--kexi/plugins/macros/kexipart/keximacroview.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kexi/plugins/macros/kexipart/keximacroview.cpp b/kexi/plugins/macros/kexipart/keximacroview.cpp
index e13483c1..e9f9cd33 100644
--- a/kexi/plugins/macros/kexipart/keximacroview.cpp
+++ b/kexi/plugins/macros/kexipart/keximacroview.cpp
@@ -62,8 +62,8 @@ class KexiMacroView::Private
};
-KexiMacroView::KexiMacroView(KexiMainWindow *mainwin, TQWidget *tqparent, KoMacro::Macro* const macro, const char* name)
- : KexiViewBase(mainwin, tqparent, (name ? name : "KexiMacroView"))
+KexiMacroView::KexiMacroView(KexiMainWindow *mainwin, TQWidget *parent, KoMacro::Macro* const macro, const char* name)
+ : KexiViewBase(mainwin, parent, (name ? name : "KexiMacroView"))
, d( new Private(macro) )
{
//kdDebug() << "KexiMacroView::KexiMacroView() Ctor" << endl;
@@ -164,7 +164,7 @@ void KexiMacroView::execute(TQObject* sender)
KSharedPtr<KoMacro::Context> context = d->macro->execute(sender);
if(context->hadException()) {
KexiMacroError* error = new KexiMacroError(
- mainWin(), // The tqparent KexiMainWindow
+ mainWin(), // The parent KexiMainWindow
context // The KoMacro::Context where the error occured.
);
error->exec();